pub struct CreateCheckpoint {
pub checkpoint: Pubkey,
pub checkpoint_config: Pubkey,
pub pda_signer: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateCheckpoint.
Fields
checkpoint: Pubkeycheckpoint_config: Pubkeypda_signer: Pubkeypayer: Pubkeysystem_program: PubkeyTrait Implementations
Sourceimpl BorshSerialize for CreateCheckpointwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CreateCheckpointwhere
Pubkey: BorshSerialize,
Sourceimpl ToAccountMetas for CreateCheckpoint
impl ToAccountMetas for CreateCheckpoint
Sourcefn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
fn to_account_metas(&self, is_signer: Option<bool>) -> Vec<AccountMeta>
is_signer is given as an optional override for the signer meta field.
This covers the edge case when a program-derived-address needs to relay
a transaction from a client to another program but sign the transaction
before the relay. The client cannot mark the field as a signer, and so
we have to override the is_signer meta field given by the client.Auto Trait Implementations
impl Freeze for CreateCheckpoint
impl RefUnwindSafe for CreateCheckpoint
impl Send for CreateCheckpoint
impl Sync for CreateCheckpoint
impl Unpin for CreateCheckpoint
impl UnsafeUnpin for CreateCheckpoint
impl UnwindSafe for CreateCheckpoint