pub struct CreateCheckpoint {
pub blober: Pubkey,
pub proof: [u8; 260],
pub public_values: Vec<u8>,
pub verification_key: String,
pub slot: u64,
}Expand description
Instruction.
Fields
blober: Pubkeyproof: [u8; 260]public_values: Vec<u8>verification_key: Stringslot: u64Trait Implementations
Sourceimpl BorshDeserialize for CreateCheckpointwhere
Pubkey: BorshDeserialize,
[u8; 260]: BorshDeserialize,
Vec<u8>: BorshDeserialize,
String: BorshDeserialize,
u64: BorshDeserialize,
impl BorshDeserialize for CreateCheckpointwhere
Pubkey: BorshDeserialize,
[u8; 260]: BorshDeserialize,
Vec<u8>: BorshDeserialize,
String: BorshDeserialize,
u64: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CreateCheckpointwhere
Pubkey: BorshSerialize,
[u8; 260]: BorshSerialize,
Vec<u8>: BorshSerialize,
String: BorshSerialize,
u64: BorshSerialize,
impl BorshSerialize for CreateCheckpointwhere
Pubkey: BorshSerialize,
[u8; 260]: BorshSerialize,
Vec<u8>: BorshSerialize,
String: BorshSerialize,
u64: BorshSerialize,
Sourceimpl Discriminator for CreateCheckpoint
impl Discriminator for CreateCheckpoint
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl InstructionData for CreateCheckpoint
impl InstructionData for CreateCheckpoint