pub struct CheckpointConfig {
pub blober: Pubkey,
pub authority: Pubkey,
}Fields
blober: PubkeyTrait Implementations
Sourceimpl AccountDeserialize for CheckpointConfig
impl AccountDeserialize for CheckpointConfig
Sourcefn try_deserialize(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize(buf: &mut &[u8]) -> Result<Self>
Deserializes previously initialized account data. Should fail for all
uninitialized accounts, where the bytes are zeroed. Implementations
should be unique to a particular account type so that one can never
successfully deserialize the data of one account type into another.
For example, if the SPL token program were to implement this trait,
it should be impossible to deserialize a
Mint account into a token
Account.Sourcefn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
fn try_deserialize_unchecked(buf: &mut &[u8]) -> Result<Self>
Deserializes account data without checking the account discriminator.
This should only be used on account initialization, when the bytes of
the account are zeroed.
Sourceimpl AccountSerialize for CheckpointConfig
impl AccountSerialize for CheckpointConfig
Sourceimpl BorshDeserialize for CheckpointConfigwhere
Pubkey: BorshDeserialize,
impl BorshDeserialize for CheckpointConfigwhere
Pubkey: BorshDeserialize,
fn deserialize_reader<R: Read>(reader: &mut R) -> Result<Self, Error>
Sourcefn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
fn deserialize(buf: &mut &[u8]) -> Result<Self, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
Sourcefn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.
fn try_from_reader<R>(reader: &mut R) -> Result<Self, Error>where
R: Read,
Sourceimpl BorshSerialize for CheckpointConfigwhere
Pubkey: BorshSerialize,
impl BorshSerialize for CheckpointConfigwhere
Pubkey: BorshSerialize,
Sourceimpl Clone for CheckpointConfig
impl Clone for CheckpointConfig
Sourcefn clone(&self) -> CheckpointConfig
fn clone(&self) -> CheckpointConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CheckpointConfig
impl Debug for CheckpointConfig
Sourceimpl Discriminator for CheckpointConfig
impl Discriminator for CheckpointConfig
Sourceconst DISCRIMINATOR: &'static [u8]
const DISCRIMINATOR: &'static [u8]
Discriminator slice. Read more
Sourceimpl Ord for CheckpointConfig
impl Ord for CheckpointConfig
Sourcefn cmp(&self, other: &CheckpointConfig) -> Ordering
fn cmp(&self, other: &CheckpointConfig) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for CheckpointConfig
impl PartialEq for CheckpointConfig
Sourceimpl PartialOrd for CheckpointConfig
impl PartialOrd for CheckpointConfig
Sourceimpl Space for CheckpointConfig
impl Space for CheckpointConfig
const INIT_SPACE: usize
impl Eq for CheckpointConfig
impl StructuralPartialEq for CheckpointConfig